<?php

namespace LitePress\LP_Translate\MT;

use Loco_error_AdminNotices;
use Loco_Locale;
use WP_Http;

class MT {

    function translator_filter_apis( array $apis ) {
        $apis[] = array(
            'id'   => 'litepress',
            'key'  => '123',
            'url'  => 'https://litepress.cn/translate',
            'name' => 'LitePress 机器翻译引擎',
        );

        return $apis;
    }

    function translator_ajax_init() {
        add_filter( 'loco_api_translate_litepress', array( $this, 'translator_process_batch' ), 0, 3 );
    }

    function translator_process_batch( array $sources, Loco_Locale $Locale, array $config ) {
        $targets = array();
        $r       = $this->translator_translate_word( $sources );
        foreach ( $sources as $source ) {
            $targets[] = isset( $r[ $source ] ) ? $r[ $source ] : '';
        }

        return $targets;
    }

    function translator_translate_word( array $sources ) {
        /*
         * 该钩子用于在机器翻译开始前执行一些动作
         */
        do_action( 'pre_translate_word', $sources );

        $args = array(
            'headers' => array(
                'Accept-Encoding' => 'gzip',
            ),
            'timeout' => 1000,
            'body'    => array(
                'originals' => json_encode( $sources )
            ),
        );
        $r    = wp_remote_post( 'https://api.litepress.cn/mt/translate', $args );
        if ( is_wp_error( $r ) ) {
            Loco_error_AdminNotices::err( "LitePress 机器翻译引擎请求失败：{$r->get_error_message()}" );

            return array();
        }

        $status_code = wp_remote_retrieve_response_code( $r );
        if ( WP_Http::OK !== $status_code ) {
            Loco_error_AdminNotices::err( "LitePress 机器翻译引擎请求失败，接口返回状态码为：$status_code" );

            return array();
        }

        $body = wp_remote_retrieve_body( $r );

        $targets = json_decode( $body, true );
        if ( isset( $targets['error'] ) ) {
            Loco_error_AdminNotices::err( "LitePress 机器翻译引擎请求失败：{$targets['error']}" );

            return array();
        }

        return $targets;
    }
}
